@@ -7,11 +7,13 @@ import gzip
 import json
 import glob
 import hashlib
+import shlex
 import shutil
 import tempfile
 import logging
 import subprocess
 from contextlib import contextmanager, ExitStack
+from typing import List
 
 import ruamel.yaml
 import click
@@ -156,7 +158,6 @@ def tar_directory(path, tarpath,sudo=False,**kwargs):
     cmd.extend(["-C", path])
     cmd.extend(["-acf", tarpath])
     cmd.extend(os.listdir(path))
-    print('aaa',cmd)
     return run_cmd(cmd,**kwargs)
 
 @cli.command()
@@ -574,7 +575,7 @@ def mounted_image(imagepath,mountpath,firmware_path:str='boot'):
             if not os.path.exists(firmware_mount_path): 
                 print(f'create {firmware_mount_path}')
                 subprocess.call(['mkdir',firmware_mount_path])
-            stack.enter_context(loop_mounted(input_path,firmware_mount_path,offset=offsets[1]))
+            stack.enter_context(loop_mounted(input_path,firmware_mount_path,offset=offsets[0]))
             yield
 
 @cli.command()
@@ -594,8 +595,9 @@ def mount_image(ctx,imagepath,mountpath,firmware_path,not_interactive):
 @cli.command()
 @click.argument('imagepath')
 @click.option('-n','--image-name')
-@click.option('-p','--platform')
-def iso_to_docker(imagepath,image_name:str=None,platform:str=None):
+@click.option('-p','--platform',help='the docker image architecture/platform')
+@click.option('-h','--hooks',multiple=True,help='specify hooks before taring up the iso filesystem, the hook will get root fs path as argument')
+def iso_to_docker(imagepath,image_name:str=None,platform:str=None,hooks:List[str]=[]):
     if not image_name:
         image_name = os.path.basename(imagepath).split('.',1)[0]
     with tempfile.TemporaryDirectory() as outdir:
@@ -603,6 +605,13 @@ def iso_to_docker(imagepath,image_name:str=None,platform:str=None):
             print(f'mounting iso to {tempdir}')
             with mounted_image(imagepath,tempdir):
                 tar_path = os.path.join(outdir,'image.tar')
+                for hook in hooks:
+                    cmd =
+                    if os.path.isfile(hook):
+                        cmd = [hook,tempdir]
+                    else:
+                        cmd = shlex.split(hook) + tempdir
+                    subprocess.run(cmd)
                 print(f'tar the tempdir: {tempdir}')
                 tar_directory.callback(tempdir,tar_path,sudo=True)
         print(f'import the {tar_path} to docker')
